@@ -432,9 +432,11 @@ class ElucidatedImagen(nn.Module):
         self.reset_unets_all_one_device(device = device)
 
         if exists(texts) and not exists(text_embeds) and not self.unconditional:
-            text_embeds, text_masks = t5_encode_text(texts, name = self.text_encoder_name)
+            text_embeds, text_masks = t5_encode_text(texts, name = self.text_encoder_name, return_attn_mask = True)
             text_embeds, text_masks = map(lambda t: t.to(device), (text_embeds, text_masks))
 
+        text_masks = default(text_masks, lambda: torch.any(text_embeds != 0., dim = -1))
+
         if not self.unconditional:
             batch_size = text_embeds.shape[0]
 
@@ -532,9 +534,11 @@ class ElucidatedImagen(nn.Module):
         if exists(texts) and not exists(text_embeds) and not self.unconditional:
             assert len(texts) == len(images), 'number of text captions does not match up with the number of images given'
 
-            text_embeds, text_masks = t5_encode_text(texts, name = self.text_encoder_name)
+            text_embeds, text_masks = t5_encode_text(texts, name = self.text_encoder_name, return_attn_mask = True)
             text_embeds, text_masks = map(lambda t: t.to(images.device), (text_embeds, text_masks))
 
+        text_masks = default(text_masks, lambda: torch.any(text_embeds != 0., dim = -1))
+
         assert not (self.condition_on_text and not exists(text_embeds)), 'text or text encodings must be passed into decoder if specified'
         assert not (not self.condition_on_text and exists(text_embeds)), 'decoder specified not to be conditioned on text, yet it is presented'
 
